/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View.AccuracyTests.Enh6
{

    /// <summary>
    /// Unit test fixture for DependencyRenderer.
    ///
    /// Testing of DependencyRenderer only handles the properties. The accuracy of the rendering algorithm
    /// is tested in the FixedGridLayoutManager.
    /// </summary>
    [TestFixture]
    public class Enh6
    {
    	private string dir = @"../../test_files/enh6";
		protected DependencyRenderer renderer = null;
		protected Dependency a = null;
		protected Dependency b = null;
		protected Dependency c = null;
		protected Dependency d = null;
		protected Dependency e = null;
		protected Dependency f = null;
		protected Dependency g = null;

		[SetUp]
		protected void SetUp()
		{
			renderer = new DependencyRenderer();

			a = new Dependency("A");
			b = new Dependency("B");
			c = new Dependency("C");
			d = new Dependency("D");
			e = new Dependency("E");
			f = new Dependency("F");
			g = new Dependency("G");

		}

        [Test]
        public void RenderAllWithRoot1()
        {
			renderer.AddDiagramRenderer(new SVGRenderer(dir));
			a.AddDependant(b);
			b.AddDependant(c);
			renderer.RenderAll(a);

            Assert.IsTrue(File.Exists(dir + "/a.svg"), "Output does not exist.");           
            File.Delete(dir + "/a.svg");
            Assert.IsTrue(File.Exists(dir + "/b.svg"), "Output does not exist.");           
            File.Delete(dir + "/b.svg");
            Assert.IsTrue(File.Exists(dir + "/c.svg"), "Output does not exist.");           
            File.Delete(dir + "/c.svg");
        }
        
		[Test]
		public void RenderAllWithoutRoot1()
		{
			renderer.AddDiagramRenderer(new SVGRenderer(dir));
			a.AddDependant(b);
			b.AddDependant(c);
			renderer.RenderAll(a, false);

			Assert.IsFalse(File.Exists(dir + "/a.svg"), "Output should not exist.");           
			Assert.IsTrue(File.Exists(dir + "/b.svg"), "Output does not exist.");           
			File.Delete(dir + "/b.svg");
			Assert.IsTrue(File.Exists(dir + "/c.svg"), "Output does not exist.");           
			File.Delete(dir + "/c.svg");
		}
        
		[Test]
		public void RenderAllWithRoot2()
		{
			renderer.AddDiagramRenderer(new SVGRenderer(dir));
			a.AddDependant(b);
			a.AddDependant(c);
			b.AddDependant(d);
			b.AddDependant(e);
			e.AddDependant(c);
			e.AddDependant(f);
			renderer.RenderAll(a);

			Assert.IsTrue(File.Exists(dir + "/a.svg"), "Output does not exist.");           
			File.Delete(dir + "/a.svg");
			Assert.IsTrue(File.Exists(dir + "/b.svg"), "Output does not exist.");           
			File.Delete(dir + "/b.svg");
			Assert.IsTrue(File.Exists(dir + "/c.svg"), "Output does not exist.");           
			File.Delete(dir + "/c.svg");
			Assert.IsTrue(File.Exists(dir + "/d.svg"), "Output does not exist.");           
			File.Delete(dir + "/d.svg");
			Assert.IsTrue(File.Exists(dir + "/e.svg"), "Output does not exist.");           
			File.Delete(dir + "/e.svg");
			Assert.IsTrue(File.Exists(dir + "/f.svg"), "Output does not exist.");           
			File.Delete(dir + "/f.svg");
		}
		[Test]
		public void RenderAllWithoutRoot2()
		{
			renderer.AddDiagramRenderer(new SVGRenderer(dir));
			a.AddDependant(b);
			a.AddDependant(c);
			b.AddDependant(d);
			b.AddDependant(e);
			e.AddDependant(c);
			e.AddDependant(f);
			renderer.RenderAll(a, false);

			Assert.IsFalse(File.Exists(dir + "/a.svg"), "Output should not exist.");           
			Assert.IsTrue(File.Exists(dir + "/b.svg"), "Output does not exist.");           
			File.Delete(dir + "/b.svg");
			Assert.IsTrue(File.Exists(dir + "/c.svg"), "Output does not exist.");           
			File.Delete(dir + "/c.svg");
			Assert.IsTrue(File.Exists(dir + "/d.svg"), "Output does not exist.");           
			File.Delete(dir + "/d.svg");
			Assert.IsTrue(File.Exists(dir + "/e.svg"), "Output does not exist.");           
			File.Delete(dir + "/e.svg");
			Assert.IsTrue(File.Exists(dir + "/f.svg"), "Output does not exist.");           
			File.Delete(dir + "/f.svg");
		}
	}

}
