/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.AccuracyTests.Enh6;

import java.io.File;
import java.util.HashSet;
import java.util.Set;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.RendererException;
import com.topcoder.rules.dependencymap.view.SVGRenderer;

/**
 * Tets for the enhancement 3, using the configuration manager
 *
 * @author cucu
 * @version 1.0
 */
public class Enh6Tests extends TestCase {
    private SpyDependencyRenderer renderer = null;
    private Dependency a = null;
    private Dependency b = null;
    private Dependency c = null;
    private Dependency d = null;
    private Dependency e = null;
    private Dependency f = null;

    /**
     * Set up for each test.
     */
    public void setUp() {
        renderer = new SpyDependencyRenderer();
        renderer.addDiagramRenderer(new SVGRenderer(new File("null")));

        a = new Dependency("A");
        b = new Dependency("B");
        c = new Dependency("C");
        d = new Dependency("D");
        e = new Dependency("E");
        f = new Dependency("F");
    }

    /**
     * Test rendering all the dependencies including the root
     */
    public void testAllWithRoot1() throws RendererException {
        a.addDependant(b);
        b.addDependant(c);
        renderer.renderAll(a);

        Set expected = new HashSet();
        expected.add("A");
        expected.add("B");
        expected.add("C");
        assertEquals("bad calls to render", expected, renderer.getLog());
    }

    /**
     * Test rendering all the dependencies excluding the root
     */
    public void testAllWithoutRoot1() throws RendererException {
        a.addDependant(b);
        b.addDependant(c);
        renderer.renderAll(a, false);

        Set expected = new HashSet();
        expected.add("B");
        expected.add("C");
        assertEquals("bad calls to render", expected, renderer.getLog());
    }


    /**
     * Test rendering all the dependencies including the root
     */
    public void testAllWithRoot2() throws RendererException {
        a.addDependant(b);
        a.addDependant(c);
        b.addDependant(d);
        b.addDependant(e);
        e.addDependant(c);
        e.addDependant(f);
        renderer.renderAll(a);

        Set expected = new HashSet();
        expected.add("A");
        expected.add("B");
        expected.add("C");
        expected.add("D");
        expected.add("E");
        expected.add("F");
        assertEquals("bad calls to render", expected, renderer.getLog());
    }

    /**
     * Test rendering all the dependencies excluding the root
     */
    public void testAllWithoutRoot2() throws RendererException {
        a.addDependant(b);
        a.addDependant(c);
        b.addDependant(d);
        b.addDependant(e);
        e.addDependant(c);
        e.addDependant(f);
        renderer.renderAll(a, false);

        Set expected = new HashSet();
        expected.add("B");
        expected.add("C");
        expected.add("D");
        expected.add("E");
        expected.add("F");
        assertEquals("bad calls to render", expected, renderer.getLog());
    }

}